@@ -18,20 +18,18 @@
 	Contact : jmgr@jmgr.info
 */
 
-#include "globalshortcut/globalshortcutmanager.h"
-#include "qxtcommandoptions/qxtcommandoptions.h"
 #include "actioninstance.h"
 #include "version.h"
 #include "mainclass.h"
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include "qtsingleapplication/qtsingleapplication.h"
-#else
-#include "nativeeventfilteringapplication.h"
-#endif
 #include "global.h"
 #include "settings.h"
 #include "languages.h"
 
+#ifdef ACT_PROFILE
+#include "highresolutiontimer.h"
+#endif
+
 #include <ctime>
 
 #include <QApplication>
@@ -43,12 +41,10 @@
 #include <QUrl>
 #include <QNetworkProxy>
 #include <QDataStream>
-
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include <QUrlQuery>
-#endif
+#include <QCommandLineParser>
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 #undef signals
 #include <libnotify/notify.h>
 #define signals
@@ -66,7 +62,9 @@
 
 static void cleanup()
 {
-	ActionTools::GlobalShortcutManager::clear();
+#ifdef Q_OS_UNIX
+	notify_uninit();
+#endif
 }
 
 #ifdef Q_OS_WIN
@@ -106,85 +104,74 @@ int main(int argc, char **argv)
         #error("You need Qt 5.4.0 or later to compile Actiona Executer");
 #endif
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-    QtSingleApplication app("actiona-exec", argc, argv);
-#else
-    ActionTools::NativeEventFilteringApplication app("actiona-exec", argc, argv);
-#endif
+	QtSingleApplication app(QStringLiteral("actiona-exec"), argc, argv);
 	app.setQuitOnLastWindowClosed(false);
 
 	qAddPostRoutine(cleanup);
 
-	qsrand(std::time(NULL));
+	qsrand(static_cast<uint>(std::time(nullptr)));
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
     notify_init("Actiona executer");
 #endif
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
-    QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
-#endif
+	QCommandLineParser optionsParser;
+	optionsParser.setApplicationDescription(QObject::tr("Emulates clics, key presses and other actions."));
+	optionsParser.addHelpOption();
+	optionsParser.addVersionOption();
 
-    QxtCommandOptions preOptions;
+	optionsParser.addOption({{QStringLiteral("p"), QStringLiteral("portable")}, QObject::tr("Starts in portable mode, storing the settings in the executable folder.")});
 
-    preOptions.add("portable", QObject::tr("starts in portable mode, storing the settings in the executable folder"));
-    preOptions.alias("portable", "p");
-    preOptions.parse(QCoreApplication::arguments());
+	optionsParser.parse(app.arguments());
 
-    if(preOptions.count("portable") > 0)
-    {
-        QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, QApplication::applicationDirPath() + "/userSettings");
-        QSettings::setPath(QSettings::IniFormat, QSettings::SystemScope, QApplication::applicationDirPath() + "/systemSettings");
-        QSettings::setDefaultFormat(QSettings::IniFormat);
-    }
+	if(optionsParser.isSet(QStringLiteral("portable")))
+	{
+		QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, QApplication::applicationDirPath() + QStringLiteral("/userSettings"));
+		QSettings::setPath(QSettings::IniFormat, QSettings::SystemScope, QApplication::applicationDirPath() + QStringLiteral("/systemSettings"));
+		QSettings::setDefaultFormat(QSettings::IniFormat);
+	}
 
     QString locale = Tools::Languages::locale();
 
-    Tools::Languages::installTranslator("qtbase", locale);
-    Tools::Languages::installTranslator("qtlocation", locale);
-    Tools::Languages::installTranslator("qtmultimedia", locale);
-    Tools::Languages::installTranslator("qtscript", locale);
-    Tools::Languages::installTranslator("qtxmlpatterns", locale);
-    Tools::Languages::installTranslator("tools", locale);
-    Tools::Languages::installTranslator("actiontools", locale);
-    Tools::Languages::installTranslator("executer", locale);
-    Tools::Languages::installTranslator("actexecuter", locale);
 
-    const QStringList &arguments = QCoreApplication::arguments();
+    Tools::Languages::installTranslator(QStringLiteral("qtbase"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("qtlocation"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("qtmultimedia"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("qtscript"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("qtxmlpatterns"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("tools"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("actiontools"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("executer"), locale);
+    Tools::Languages::installTranslator(QStringLiteral("actexecuter"), locale);
+
+	optionsParser.addOptions(
+	{
+		{{QStringLiteral("c"), QStringLiteral("code")}, QObject::tr("Switch to code mode, may not be used with -s.")},
+		{{QStringLiteral("s"), QStringLiteral("script")}, QObject::tr("Switch to script mode, may not be used with -c.")},
+		{{QStringLiteral("Q"), QStringLiteral("nocodeqt")}, QObject::tr("Do not include the Qt library into the code.")},
+		{{QStringLiteral("proxy-mode")}, QObject::tr(R"(Sets the proxy mode, values are "none", "system" (default) or "custom".)")},
+		{{QStringLiteral("proxy-type")}, QObject::tr(R"(Sets the custom proxy type, values are "http" or "socks" (default).)")},
+		{{QStringLiteral("proxy-host")}, QObject::tr("Sets the custom proxy host.")},
+		{{QStringLiteral("proxy-port")}, QObject::tr("Sets the custom proxy port.")},
+		{{QStringLiteral("proxy-user")}, QObject::tr("Sets the custom proxy user.")},
+		{{QStringLiteral("proxy-password")}, QObject::tr("Sets the custom proxy password.")},
+	});
 
-    QxtCommandOptions options;
-    options.setFlagStyle(QxtCommandOptions::DoubleDash);
-    options.setScreenWidth(0);
-    options.add("code", QObject::tr("switch to code mode, may not be used with -s"));
-    options.alias("code", "c");
-    options.add("script", QObject::tr("switch to script mode, may not be used with -c"));
-    options.alias("script", "s");
-    options.add("nocodeqt", QObject::tr("do not include the Qt library into the code"));
-    options.alias("nocodeqt", "Q");
-    options.add("portable", QObject::tr("starts in portable mode, storing the settings in the executable folder"));
-    options.alias("portable", "p");
-    options.add("proxy-mode", QObject::tr("sets the proxy mode, values are \"none\", \"system\" (default) or \"custom\""));
-    options.add("proxy-type", QObject::tr("sets the custom proxy type, values are \"http\" or \"socks\" (default)"));
-    options.add("proxy-host", QObject::tr("sets the custom proxy host"));
-    options.add("proxy-port", QObject::tr("sets the custom proxy port"));
-    options.add("proxy-user", QObject::tr("sets the custom proxy user"));
-    options.add("proxy-password", QObject::tr("sets the custom proxy password"));
 #ifdef Q_OS_WIN
-    options.add("console", QObject::tr("create a console to see debug output"));
-    options.add("pause-at-end", QObject::tr("wait for user input at the end of the execution, used only with --console"));
+	optionsParser.addOption({QStringLiteral("console"), QObject::tr("create a console to see debug output.")});
+	optionsParser.addOption({QStringLiteral("pause-at-end"), QObject::tr("wait for user input at the end of the execution, used only with --console.")});
 #endif
-    options.add("version", QObject::tr("show the program version"));
-    options.alias("version", "v");
-    options.add("help", QObject::tr("show this help text"));
-    options.alias("help", "h");
-    options.parse(arguments);
+
+	optionsParser.addPositionalArgument(QStringLiteral("filepath"), QObject::tr("The filepath of a script/code file to execute."));
+
+	optionsParser.process(app);
 
 #ifdef Q_OS_WIN
-    if(options.count("console"))
+	if(optionsParser.isSet(QStringLiteral("console")))
     {
         createConsole();
 
-        if(options.count("pause-at-end"))
+		if(optionsParser.isSet(QStringLiteral("pause-at-end")))
             qAddPostRoutine(pause);
     }
 #endif
@@ -200,30 +187,17 @@ int main(int argc, char **argv)
 	qRegisterMetaTypeStreamOperators<ActionTools::SubParameter>("SubParameter");
 	qRegisterMetaTypeStreamOperators<Tools::Version>("Version");
 
-	if(options.count("version"))
-	{
-		QTextStream stream(stdout);
-        stream << "Actiona Executer version " << Global::ACTIONA_VERSION.toString() << ", script version " << Global::SCRIPT_VERSION.toString() << "\n";
-		stream.flush();
-		return 0;
-	}
-	if(options.count("help") || options.showUnrecognizedWarning() || options.positional().count() < 1 || (options.count("code") && options.count("script")))
-	{
-		QTextStream stream(stdout);
-		stream << QObject::tr("usage: ") << QCoreApplication::arguments().at(0) << " " << QObject::tr("[parameters]") << " " << QObject::tr("filename") << "\n";
-		stream << QObject::tr("Parameters are:") << "\n";
-		stream << options.getUsage();
-		stream.flush();
-		return -1;
-	}
+	const auto &positionalArguments = optionsParser.positionalArguments();
+	if(positionalArguments.count() < 1 || (optionsParser.isSet(QStringLiteral("code")) && optionsParser.isSet(QStringLiteral("script"))))
+		optionsParser.showHelp(-1);
 
-	app.addLibraryPath(QApplication::applicationDirPath() + "/actions");
-	app.addLibraryPath(QApplication::applicationDirPath() + "/plugins");
+	app.addLibraryPath(QApplication::applicationDirPath() + QStringLiteral("/actions"));
+	app.addLibraryPath(QApplication::applicationDirPath() + QStringLiteral("/plugins"));
 
-	if(!options.count("nocodeqt"))
-		app.addLibraryPath(QApplication::applicationDirPath() + "/code");
+	if(!optionsParser.isSet(QStringLiteral("nocodeqt")))
+		app.addLibraryPath(QApplication::applicationDirPath() + QStringLiteral("/code"));
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 	{
 #ifdef ACT_PROFILE
 		Tools::HighResolutionTimer timer("Load key codes");
@@ -234,18 +208,19 @@ int main(int argc, char **argv)
 
 	// Proxy settings
 	int proxyMode = ActionTools::Settings::PROXY_SYSTEM;
-	if(options.value("proxy-mode").toString() == "none")
+	if(optionsParser.value(QStringLiteral("proxy-mode")) == QLatin1String("none"))
 		proxyMode = ActionTools::Settings::PROXY_NONE;
-	else if(options.value("proxy-mode").toString() == "custom")
+	else if(optionsParser.value(QStringLiteral("proxy-mode")) == QLatin1String("custom"))
 		proxyMode = ActionTools::Settings::PROXY_CUSTOM;
-	else if(options.value("proxy-mode").toString() == "system")
+	else if(optionsParser.value(QStringLiteral("proxy-mode")) == QLatin1String("system"))
 		proxyMode = ActionTools::Settings::PROXY_SYSTEM;
-	else if(!options.value("proxy-mode").toString().isEmpty())
+	else if(!optionsParser.value(QStringLiteral("proxy-mode")).isEmpty())
 	{
 		QTextStream stream(stdout);
-		stream << QObject::tr("Unknown proxy mode, values are \"none\", \"system\" (default) or \"custom\"") << "\n";
+		stream << QObject::tr(R"(Unknown proxy mode, values are "none", "system" (default) or "custom")") << "\n";
 		stream.flush();
-		return -1;
+
+		optionsParser.showHelp(-1);
 	}
 
 	QNetworkProxy proxy;
@@ -269,16 +244,17 @@ int main(int argc, char **argv)
 	case ActionTools::Settings::PROXY_CUSTOM:
 		{
 			int type = ActionTools::Settings::PROXY_TYPE_SOCKS5;
-			if(options.value("proxy-type").toString() == "http")
+			if(optionsParser.value(QStringLiteral("proxy-type")) == QLatin1String("http"))
 				type = ActionTools::Settings::PROXY_TYPE_HTTP;
-			else if(options.value("proxy-type").toString() == "socks")
+			else if(optionsParser.value(QStringLiteral("proxy-type")) == QLatin1String("socks"))
 				type = ActionTools::Settings::PROXY_TYPE_SOCKS5;
-			else if(!options.value("proxy-type").toString().isEmpty())
+			else if(!optionsParser.value(QStringLiteral("proxy-type")).isEmpty())
 			{
 				QTextStream stream(stdout);
-				stream << QObject::tr("Unknown proxy type, values are \"http\" or \"socks\" (default)") << "\n";
+				stream << QObject::tr(R"(Unknown proxy type, values are "http" or "socks" (default))") << "\n";
 				stream.flush();
-				return -1;
+
+				optionsParser.showHelp(-1);
 			}
 
 			QNetworkProxy proxy;
@@ -288,18 +264,18 @@ int main(int argc, char **argv)
 			else
 				proxy.setType(QNetworkProxy::Socks5Proxy);
 
-			proxy.setHostName(options.value("proxy-host").toString());
-			proxy.setPort(options.value("proxy-port").toInt());
-			proxy.setUser(options.value("proxy-user").toString());
-			proxy.setPassword(options.value("proxy-password").toString());
+			proxy.setHostName(optionsParser.value(QStringLiteral("proxy-host")));
+			proxy.setPort(static_cast<quint16>(optionsParser.value(QStringLiteral("proxy-port")).toUInt()));
+			proxy.setUser(optionsParser.value(QStringLiteral("proxy-user")));
+			proxy.setPassword(optionsParser.value(QStringLiteral("proxy-password")));
 		}
 		break;
 	}
 
 	QNetworkProxy::setApplicationProxy(proxy);
 
-	QUrl protocolUrl = QUrl::fromEncoded(arguments.at(1).toUtf8());
-    if(protocolUrl.isValid() && protocolUrl.scheme() != "actiona")
+	QUrl protocolUrl = QUrl::fromEncoded(positionalArguments.first().toUtf8());
+	if(protocolUrl.isValid() && protocolUrl.scheme() != QLatin1String("actiona"))
 		protocolUrl = QUrl();
 
 	MainClass::ExecutionMode executionMode = MainClass::Unknown;
@@ -307,37 +283,33 @@ int main(int argc, char **argv)
 
 	if(protocolUrl.isValid())
 	{
-		QString mode;
-        using QStringPair = QPair<QString, QString>;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-        for(const QStringPair &queryItem: QUrlQuery(protocolUrl.query()).queryItems())
-#else
-        for(const QStringPair &queryItem: protocolUrl.queryItems())
-#endif
+        QString mode;
+        for(const auto &queryItem: QUrlQuery(protocolUrl.query()).queryItems())
 		{
-			if(queryItem.first == "mode")
+			if(queryItem.first == QLatin1String("mode"))
 			{
 				mode = queryItem.second;
 				break;
 			}
 		}
 
-		if(mode == "code")
+		if(mode == QLatin1String("code"))
 			executionMode = MainClass::Code;
-		else if(mode == "script")
+		else if(mode == QLatin1String("script"))
 			executionMode = MainClass::Script;
 		else
 		{
-			if(protocolUrl.path().endsWith(".ascr"))
+			if(protocolUrl.path().endsWith(QStringLiteral(".ascr")))
 				executionMode = MainClass::Script;
-			else if(protocolUrl.path().endsWith(".acod"))
+			else if(protocolUrl.path().endsWith(QStringLiteral(".acod")))
 				executionMode = MainClass::Code;
 			else
 			{
 				QTextStream stream(stdout);
 				stream << QObject::tr("Unknown execution mode, please specify mode=script or mode=code") << "\n";
 				stream.flush();
-				return -1;
+
+				optionsParser.showHelp(-1);
 			}
 		}
 
@@ -346,24 +318,25 @@ int main(int argc, char **argv)
 	}
 	else
 	{
-		QString filename = options.positional().at(0);
+		QString filename = positionalArguments.first();
 
-		if(options.count("code"))
+		if(optionsParser.isSet(QStringLiteral("code")))
 			executionMode = MainClass::Code;
-		else if(options.count("script"))
+		else if(optionsParser.isSet(QStringLiteral("script")))
 			executionMode = MainClass::Script;
 		else
 		{
-			if(filename.endsWith(".ascr"))
+			if(filename.endsWith(QStringLiteral(".ascr")))
 				executionMode = MainClass::Script;
-			else if(filename.endsWith(".acod"))
+			else if(filename.endsWith(QStringLiteral(".acod")))
 				executionMode = MainClass::Code;
 			else
 			{
 				QTextStream stream(stdout);
 				stream << QObject::tr("Unknown execution mode, please specify -s (script) or -c (code)") << "\n";
 				stream.flush();
-				return -1;
+
+				optionsParser.showHelp(-1);
 			}
 		}
 
@@ -373,6 +346,7 @@ int main(int argc, char **argv)
 			QTextStream stream(stdout);
 			stream << QObject::tr("Unable to read input file") << "\n";
 			stream.flush();
+
 			return -1;
 		}
 
