@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef WRITECLIPBOARDINSTANCE_H
-#define WRITECLIPBOARDINSTANCE_H
+#pragma once
 
 #include "actioninstance.h"
 
@@ -33,14 +32,14 @@ namespace Actions
 		Q_OBJECT
 
 	public:
-		WriteClipboardInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0)
+		WriteClipboardInstance(const ActionTools::ActionDefinition *definition, QObject *parent = nullptr)
 			: ActionTools::ActionInstance(definition, parent)											{}
 
-		void startExecution()
+		void startExecution() override
 		{
 			bool ok = true;
 
-			QString value = evaluateString(ok, "value");
+			QString value = evaluateString(ok, QStringLiteral("value"));
 
 			if(!ok)
 				return;
@@ -48,7 +47,7 @@ namespace Actions
 			QClipboard *clipboard = QApplication::clipboard();
 			clipboard->setText(value);
 
-			emit executionEnded();
+			executionEnded();
 		}
 
 	private:
@@ -56,4 +55,3 @@ namespace Actions
 	};
 }
 
-#endif // WRITECLIPBOARDINSTANCE_H
