@@ -254,7 +254,7 @@ namespace Code
 	{
 		Q_UNUSED(engine)
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 		Q_UNUSED(noErrorDialog)
 		Q_UNUSED(noConfirmDialog)
 		Q_UNUSED(noProgressDialog)
@@ -350,7 +350,7 @@ namespace Code
 	{
 		Q_UNUSED(engine)
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 		Q_UNUSED(noErrorDialog)
 		Q_UNUSED(noConfirmDialog)
 		Q_UNUSED(noProgressDialog)
@@ -446,7 +446,7 @@ namespace Code
 	{
 		Q_UNUSED(engine)
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 		movePrivate(source, destination, noErrorDialog, noConfirmDialog, noProgressDialog, allowUndo, createDestinationDirectory, context, engine);
 #endif
 #ifdef Q_OS_WIN
@@ -499,7 +499,7 @@ namespace Code
 
 	QScriptValue File::removePrivate(const QString &filename, bool noErrorDialog, bool noConfirmDialog, bool noProgressDialog, bool allowUndo, QScriptContext *context, QScriptEngine *engine)
 	{
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 		Q_UNUSED(noErrorDialog)
 		Q_UNUSED(noConfirmDialog)
 		Q_UNUSED(noProgressDialog)
@@ -564,7 +564,7 @@ namespace Code
 
 	QString File::getErrorString(int error)
 	{
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 		Q_UNUSED(error)
 
 		return QString();
