@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef MOUSEDEVICE_H
-#define MOUSEDEVICE_H
+#pragma once
 
 #include <QPoint>
 #include <QObject>
@@ -40,7 +39,7 @@ public:
 	};
 
 	MouseDevice();
-	~MouseDevice();
+    ~MouseDevice() override;
 
 	void reset();
 
@@ -55,7 +54,7 @@ public:
 	bool wheel(int intensity = 1) const;
 
 private:
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 	int toX11Button(Button button) const;
 #endif
 #ifdef Q_OS_WIN
@@ -65,4 +64,3 @@ private:
 	bool mPressedButtons[ButtonCount];
 };
 
-#endif // MOUSEDEVICE_H
