@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef GOTOINSTANCE_H
-#define GOTOINSTANCE_H
+#pragma once
 
 #include "actioninstance.h"
 
@@ -30,21 +29,21 @@ namespace Actions
 		Q_OBJECT
 
 	public:
-		GotoInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0)
+		GotoInstance(const ActionTools::ActionDefinition *definition, QObject *parent = nullptr)
 			: ActionTools::ActionInstance(definition, parent)										{}
 
-		void startExecution()
+		void startExecution() override
 		{
 			bool ok = true;
 
-			QString line = evaluateString(ok, "line");
+			QString line = evaluateString(ok, QStringLiteral("line"));
 
 			if(!ok)
 				return;
 
 			setNextLine(line);
 
-			emit executionEnded();
+			executionEnded();
 		}
 
 	private:
@@ -52,4 +51,3 @@ namespace Actions
 	};
 }
 
-#endif // GOTOINSTANCE_H
