@@ -22,11 +22,18 @@
 
 namespace Actions
 {
-    Tools::StringListPair PixelColorInstance::comparisons = qMakePair(
-			QStringList() << "equal" << "darker" << "lighter",
-			QStringList()
-			<< QT_TRANSLATE_NOOP("PixelColorInstance::comparisons", "Equal")
-			<< QT_TRANSLATE_NOOP("PixelColorInstance::comparisons", "Darker")
-			<< QT_TRANSLATE_NOOP("PixelColorInstance::comparisons", "Lighter"));
+    Tools::StringListPair PixelColorInstance::comparisons =
+    {
+        {
+            QStringLiteral("equal"),
+            QStringLiteral("darker"),
+            QStringLiteral("lighter")
+        },
+        {
+            QStringLiteral(QT_TRANSLATE_NOOP("PixelColorInstance::comparisons", "Equal")),
+            QStringLiteral(QT_TRANSLATE_NOOP("PixelColorInstance::comparisons", "Darker")),
+            QStringLiteral(QT_TRANSLATE_NOOP("PixelColorInstance::comparisons", "Lighter"))
+        }
+    };
 }
 
