@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef PROGRESSDIALOG_H
-#define PROGRESSDIALOG_H
+#pragma once
 
 #include "basewindow.h"
 
@@ -37,7 +36,7 @@ namespace Code
 		static QScriptValue constructor(QScriptContext *context, QScriptEngine *engine);		
 		
 		ProgressDialog();
-		~ProgressDialog();
+		~ProgressDialog() override;
 		
 		void setOnCanceled(const QScriptValue &onCanceled)					{ mOnCanceled = onCanceled; }
 		
@@ -45,7 +44,7 @@ namespace Code
 		int value() const;
 		
 	public slots:
-		QString toString() const					{ return "ProgressDialog"; }
+		QString toString() const override					{ return QStringLiteral("ProgressDialog"); }
 		QScriptValue setValue(int value);
 		QScriptValue setLabelText(const QString &labelText);
 		QScriptValue setMinimum(int minimum);
@@ -63,4 +62,3 @@ namespace Code
 	};
 }
 
-#endif // PROGRESSDIALOG_H
