@@ -27,9 +27,9 @@ namespace ActionTools
 {
 	QString ActionException::ExceptionName[ExceptionCount] =
 	{
-        QT_TRANSLATE_NOOP("ActionException::ExceptionName", "Invalid parameter"),
-		QT_TRANSLATE_NOOP("ActionException::ExceptionName", "Code error"),
-		QT_TRANSLATE_NOOP("ActionException::ExceptionName", "Timeout")
+		QStringLiteral(QT_TRANSLATE_NOOP("ActionException::ExceptionName", "Invalid parameter")),
+		QStringLiteral(QT_TRANSLATE_NOOP("ActionException::ExceptionName", "Code error")),
+		QStringLiteral(QT_TRANSLATE_NOOP("ActionException::ExceptionName", "Timeout"))
 	};
 	
 	ActionException::ExceptionAction ActionException::ExceptionDefaultAction[ExceptionCount] =
@@ -41,9 +41,9 @@ namespace ActionTools
 
 	QString ActionException::ExceptionActionName[ExceptionActionCount] =
 	{
-		QT_TRANSLATE_NOOP("ActionException::ExceptionActionName", "Stop execution"),
-		QT_TRANSLATE_NOOP("ActionException::ExceptionActionName", "Skip current action"),
-		QT_TRANSLATE_NOOP("ActionException::ExceptionActionName", "Goto a line")
+		QStringLiteral(QT_TRANSLATE_NOOP("ActionException::ExceptionActionName", "Stop execution")),
+		QStringLiteral(QT_TRANSLATE_NOOP("ActionException::ExceptionActionName", "Skip current action")),
+		QStringLiteral(QT_TRANSLATE_NOOP("ActionException::ExceptionActionName", "Goto a line"))
 	};
 
 	QDataStream &operator >> (QDataStream &s, ActionException::Exception &exception)
