@@ -25,7 +25,7 @@ namespace Code
 {
 	QScriptValue Color::constructor(QScriptContext *context, QScriptEngine *engine)
 	{
-		Color *color = 0;
+		Color *color = nullptr;
 		
 		switch(context->argumentCount())
 		{
@@ -38,7 +38,7 @@ namespace Code
 				{
 					if(!QColor::isValidColor(context->argument(0).toString()))
 					{
-						throwError(context, engine, "ColorNameError", tr("Invalid color name"));
+						throwError(context, engine, QStringLiteral("ColorNameError"), tr("Invalid color name"));
 						color = new Color;
 					}
 					else
@@ -47,10 +47,10 @@ namespace Code
 				else
 				{
 					QObject *object = context->argument(0).toQObject();
-					if(Color *codeColor = qobject_cast<Color*>(object))
+					if(auto codeColor = qobject_cast<Color*>(object))
 						color = new Color(*codeColor);
 					else
-						throwError(context, engine, "ParameterTypeError", tr("Incorrect parameter type"));
+						throwError(context, engine, QStringLiteral("ParameterTypeError"), tr("Incorrect parameter type"));
 				}
 			}
 			break;
@@ -61,7 +61,7 @@ namespace Code
 			color = new Color(QColor(context->argument(0).toInt32(), context->argument(1).toInt32(), context->argument(2).toInt32(), context->argument(3).toInt32()));
 			break;
 		default:
-			throwError(context, engine, "ParameterCountError", tr("Incorrect parameter count"));
+			throwError(context, engine, QStringLiteral("ParameterCountError"), tr("Incorrect parameter count"));
 			break;
 		}
 		
@@ -161,7 +161,7 @@ namespace Code
 			return false;
 		
 		QObject *object = other.toQObject();
-		if(Color *otherColor = qobject_cast<Color*>(object))
+		if(auto otherColor = qobject_cast<Color*>(object))
 			return (otherColor == this || otherColor->mColor == mColor);
 			
 		return false;
@@ -169,7 +169,7 @@ namespace Code
 
 	QString Color::toString() const
 	{
-        return QString("Color {red: %1, green: %2, blue: %3, alpha: %4}").arg(mColor.red()).arg(green()).arg(blue()).arg(alpha());
+		return QStringLiteral("Color {red: %1, green: %2, blue: %3, alpha: %4}").arg(mColor.red()).arg(green()).arg(blue()).arg(alpha());
 	}
 	
 	QScriptValue Color::setRed(int red)
@@ -225,7 +225,7 @@ namespace Code
 	{
 		if(!QColor::isValidColor(name))
 		{
-			throwError("ColorNameError", tr("Invalid color name"));
+			throwError(QStringLiteral("ColorNameError"), tr("Invalid color name"));
 			return thisObject();
 		}
 		
