@@ -18,8 +18,7 @@
     Contact : jmgr@jmgr.info
 */
 
-#ifndef CODELINEEDITBUTTON_H
-#define CODELINEEDITBUTTON_H
+#pragma once
 
 #include "actiontools_global.h"
 
@@ -32,8 +31,7 @@ namespace ActionTools
         Q_OBJECT
 
     public:
-        explicit CodeLineEditButton(QWidget *parent = 0);
+        explicit CodeLineEditButton(QWidget *parent = nullptr);
     };
 }
 
-#endif // CODELINEEDITBUTTON_H
