@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef COLORPARAMETERDEFINITION_H
-#define COLORPARAMETERDEFINITION_H
+#pragma once
 
 #include "parameterdefinition.h"
 #include "actiontools_global.h"
@@ -35,9 +34,9 @@ namespace ActionTools
 	public:
         ColorParameterDefinition(const Name &name, QObject *parent);
 
-		void buildEditors(Script *script, QWidget *parent);
-		void load(const ActionInstance *actionInstance);
-		void save(ActionInstance *actionInstance);
+		void buildEditors(Script *script, QWidget *parent) override;
+		void load(const ActionInstance *actionInstance) override;
+		void save(ActionInstance *actionInstance) override;
 		
 	private:
 		ColorEdit *mColorEdit;
@@ -46,4 +45,3 @@ namespace ActionTools
 	};
 }
 
-#endif // COLORPARAMETERDEFINITION_H
