@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef DEVICECOPYTHREAD_H
-#define DEVICECOPYTHREAD_H
+#pragma once
 
 #include "actiontools_global.h"
 
@@ -39,7 +38,7 @@ namespace ActionTools
 		qint64 copiedData() const;
 		
 	protected:
-		void run();
+		void run() override;
 		
 	private:
 		QIODevice *mInput;
@@ -50,4 +49,3 @@ namespace ActionTools
 	};
 }
 
-#endif // DEVICECOPYTHREAD_H
