@@ -29,19 +29,19 @@ namespace ActionTools
 		: QPushButton(parent)
 	{
 		setText(QString());
-		setIcon(QIcon(":/images/help.png"));
+		setIcon(QIcon(QStringLiteral(":/images/help.png")));
 		setIconSize(QSize(16, 16));
 		setMaximumWidth(24);
 		setMaximumHeight(24);
 		
-		connect(this, SIGNAL(clicked()), this, SLOT(clicked()));
+        connect(this, &HelpButton::clicked, this, &HelpButton::onClicked);
 	}
 	
-	void HelpButton::clicked()
+    void HelpButton::onClicked()
 	{
 		if(mTopic.isEmpty())
 			return;
 
-        QDesktopServices::openUrl(QUrl(QString("http://wiki.actiona.tools/doku.php?id=%1").arg(mTopic)));
+		QDesktopServices::openUrl(QUrl(QStringLiteral("http://wiki.actiona.tools/doku.php?id=%1").arg(mTopic)));
 	}
 }
