@@ -22,8 +22,8 @@
 
 namespace ActionTools
 {
-	const char *IfActionValue::WAIT = "wait";
-	const char *IfActionValue::GOTO = "goto";
-	const char *IfActionValue::RUNCODE = "run_code";
-	const char *IfActionValue::CALLPROCEDURE = "call_procedure";
+	QLatin1String IfActionValue::WAIT = QLatin1Literal("wait");
+	QLatin1String IfActionValue::GOTO = QLatin1Literal("goto");
+	QLatin1String IfActionValue::RUNCODE = QLatin1Literal("run_code");
+	QLatin1String IfActionValue::CALLPROCEDURE = QLatin1Literal("call_procedure");
 }
