@@ -18,8 +18,7 @@
     Contact : jmgr@jmgr.info
 */
 
-#ifndef IMAGELABEL_H
-#define IMAGELABEL_H
+#pragma once
 
 #include "actiontools_global.h"
 
@@ -32,18 +31,17 @@ namespace ActionTools
         Q_OBJECT
 
     public:
-        explicit ImageLabel(QWidget *parent = 0);
+        explicit ImageLabel(QWidget *parent = nullptr);
         const QPixmap *pixmap() const { return &mPixmap; }
 
     public slots:
         void setPixmap(const QPixmap &pixmap);
 
     protected:
-        virtual void paintEvent(QPaintEvent *event);
+        void paintEvent(QPaintEvent *event) override;
 
     private:
         QPixmap mPixmap;
     };
 }
 
-#endif // IMAGELABEL_H
