@@ -120,13 +120,13 @@ sub get_utf8 {
  */
 #include <QtGlobal>
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 #include <QX11Info>
 #endif
 
 #include "keysymhelper.h"
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 namespace ActionTools
 {
 	void KeySymHelper::loadKeyCodes()
@@ -207,7 +207,7 @@ namespace ActionTools
 
 	const char *KeySymHelper::keyModifiers[] =
 	{
-		NULL, "Mode_switch", "ISO_Level3_Shift"
+		nullptr, "Mode_switch", "ISO_Level3_Shift"
 	};
 
 	const quint16 KeySymHelper::mWCharToKeySym[] =
