@@ -21,6 +21,9 @@
 #include "lineparameterdefinition.h"
 #include "linecombobox.h"
 #include "script.h"
+#include "actioninstance.h"
+
+#include <QDebug>
 
 namespace ActionTools
 {
@@ -28,17 +31,25 @@ namespace ActionTools
 	{
 		ParameterDefinition::buildEditors(script, parent);
 
-        mComboBox = new LineComboBox(script->labels(), parent);
+        script->updateLineModel();
 
-		addEditor(mComboBox);
+        mLineComboBox = new LineComboBox(*script, parent);
+
+        addEditor(mLineComboBox);
+    }
+
+    void LineParameterDefinition::load(const ActionInstance *actionInstance)
+    {
+        mLineComboBox->setFromSubParameter(actionInstance->subParameter(name().original(), QStringLiteral("value")));
+    }
+
+    void LineParameterDefinition::save(ActionInstance *actionInstance)
+    {
+        actionInstance->setSubParameter(name().original(), QStringLiteral("value"), mLineComboBox->isCode(), mLineComboBox->currentText());
+    }
 
-		emit editorBuilt();
-	}
-	
     void LineParameterDefinition::actionUpdate(Script *script)
 	{
-		ActionTools::LineComboBox *lineComboBox = qobject_cast<ActionTools::LineComboBox *>(mComboBox);
-		
-        lineComboBox->setup(script->labels());
+        script->updateLineModel();
 	}
 }
