@@ -18,10 +18,8 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef MATCHINGPOINTLIST_H
-#define MATCHINGPOINTLIST_H
+#pragma once
 
-#include <QPair>
 #include <QPoint>
 #include <QList>
 
@@ -44,4 +42,3 @@ namespace ActionTools
     using MatchingPointList = QList<MatchingPoint>;
 }
 
-#endif // MATCHINGPOINTLIST_H
