@@ -31,13 +31,11 @@ namespace ActionTools
         mSaveTarget(ResourceSaveTarget)
     {
         setWindowTitle(tr("Screenshot wizard"));
-        setWindowIcon(QIcon(":/images/capture.png"));
+		setWindowIcon(QIcon(QStringLiteral(":/images/capture.png")));
 
         addPage(new ScreenshotWizardPage(this));
         addPage(new SaveScreenshotWizardPage(script, allowSaveToClipboard, this));
     }
 
-    ScreenshotWizard::~ScreenshotWizard()
-    {
-    }
+    ScreenshotWizard::~ScreenshotWizard() = default;
 }
