@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef VARIABLEPARAMETERDEFINITION_H
-#define VARIABLEPARAMETERDEFINITION_H
+#pragma once
 
 #include "textparameterdefinition.h"
 #include "actiontools_global.h"
@@ -37,8 +36,7 @@ namespace ActionTools
 			setCategory(OUTPUT);
 		}
 
-        void buildEditors(Script *script, QWidget *parent);
+        void buildEditors(Script *script, QWidget *parent) override;
 	};
 }
 
-#endif // VARIABLEPARAMETERDEFINITION_H
