@@ -55,7 +55,7 @@ SettingsDialog::SettingsDialog(QSystemTrayIcon *systemTrayIcon, QWidget *parent)
 {
 	ui->setupUi(this);
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 	ui->fileAssociationsLabel->setVisible(false);
 	ui->associateASCRCheckBox->setVisible(false);
 	ui->associateACODCheckBox->setVisible(false);
