@@ -104,22 +104,21 @@
         <translation>Nom de paramètre incorrect : &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="467"/>
         <source>Error while evaluating parameter &quot;%1&quot;, error message: &quot;%2&quot;</source>
-        <translation>Erreur lors de l&apos;évaluation du paramètre &quot;%1&quot;, message d&apos;erreur : &quot;%2&quot;</translation>
+        <translation type="vanished">Erreur lors de l&apos;évaluation du paramètre &quot;%1&quot;, message d&apos;erreur : &quot;%2&quot;</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="624"/>
+        <location filename="../executer/executer.cpp" line="623"/>
         <source>Action design error: Invalid exception emitted (%1, line %2)</source>
         <translation>Erreur de conception de l&apos;action : Exception invalide émise (%1, ligne %2)</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="653"/>
+        <location filename="../executer/executer.cpp" line="652"/>
         <source>Invalid exception line: %1</source>
         <translation>Ligne d&apos;exception invalide : %1</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="676"/>
+        <location filename="../executer/executer.cpp" line="675"/>
         <source>Script line %1: </source>
         <translation>Ligne de script %1 : </translation>
     </message>
@@ -128,17 +127,17 @@
         <translation type="obsolete">Script %1, ligne %2 : </translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="741"/>
+        <location filename="../executer/executer.cpp" line="740"/>
         <source>Unable to find the label named &quot;%1&quot;</source>
-        <translation>Impossible de trouver le label nommé &quot;%1&quot;</translation>
+        <translation>Impossible de trouver l&apos;étiquette nommée &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="755"/>
+        <location filename="../executer/executer.cpp" line="754"/>
         <source>Incorrect Script.nextLine value: %1</source>
         <translation>Valeur de Script.nextLine incorrecte : %1</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="758"/>
+        <location filename="../executer/executer.cpp" line="757"/>
         <source>The action at line %1 is invalid</source>
         <translation>L&apos;action à la ligne %1 est invalide</translation>
     </message>
