@@ -18,18 +18,17 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef STRINGLISTPAIR_H
-#define STRINGLISTPAIR_H
+#pragma once
 
-#include <QPair>
 #include <QStringList>
 #include <QMetaType>
 
+#include <utility>
+
 namespace Tools
 {
-    using StringListPair = QPair<QStringList, QStringList>;
+    using StringListPair = std::pair<QStringList, QStringList>;
 }
 
 Q_DECLARE_METATYPE(Tools::StringListPair)
 
-#endif // STRINGLISTPAIR_H
